@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.87 2013/02/05 10:32:31 jasper Exp $
+# $OpenBSD: Quirks.pm,v 1.93 2013/07/09 08:56:26 jasper Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -143,7 +143,6 @@ my $stem_extensions = {
 	'openh323' => 'h323plus',
 	'pwlib' => 'ptlib',
 	'e2fs-uuid' => 'e2fsprogs',
-	'puppet' => 'ruby-puppet',
 	'xmame+xmess' => ['sdlmame', 'sdlmess'],
 	'xmame' => 'sdlmame',
 	'xmess' => 'sdlmess',
@@ -307,8 +306,16 @@ my $stem_extensions = {
 	'tangogps' => 'foxtrotgps',
 	'cyrus-imapd-perl' => 'cyrus-imapd',
 	'tmw' => 'manaplus',
-        'ruby19-ruby-augeas' => 'ruby19-augeas',
-        'ruby-ruby-augeas' => 'ruby-augeas'
+	'ruby19-ruby-augeas' => 'ruby19-augeas',
+	'ruby-ruby-augeas' => 'ruby-augeas',
+	'nail' => 's-nail',
+	'mariadb-client' => 'mysql-client',
+	'mariadb-server' => 'mysql-server',
+	'mariadb-tests' => 'mysql-tests',
+	'coxpcall' => 'lua-coxpcall',
+	'lpeg' => 'lua-lpeg',
+	'ruby-facter' => 'facter',
+	'ruby-puppet' => 'puppet'
 };
 
 # ->is_base_system($handle, $state):
